@@ -9,7 +9,6 @@ import tomlkit
 from cleo.helpers import argument
 from cleo.ui.table_cell import TableCell
 from cleo.ui.table_separator import TableSeparator
-from poetry.config.source import Source
 from poetry.console.commands.command import Command
 from poetry.utils.password_manager import PasswordManager
 from tomlkit.items import Table
@@ -29,18 +28,6 @@ class RepoShowCommand(Command):
     name = "acrepo show"
     description = "Show the configuration of active dynamic repos"
 
-    # Repo prioritization has shifted between using a combination of definition order, and two flags to
-    # an clearer definition of enumerated priorities. We detect what is in play and adjust accordingly.
-    def _use_flags(self, repo: Source) -> bool:
-        return hasattr(repo, "default") and hasattr(repo, "secondary")
-
-    def _flags2prio(self, repo: Source) -> str:
-        if repo.default:  # type: ignore [attr-defined]
-            return "default"
-        elif repo.secondary:  # type: ignore [attr-defined]
-            return "secondary"
-        return "normal"
-
     def handle(self) -> int:
         try:
             for repo in RepoCollector(self.poetry.pool).repositories():
@@ -56,13 +43,13 @@ class RepoShowCommand(Command):
                         "<info>name</>",
                         f" : <c1>{repo.name}</>",
                     ],
-                    ["<info>priority</>", f" : {self._flags2prio(repo)}"]
-                    if self._use_flags(repo)
-                    else ["<info>priority</>", f" : {repo.priority.name.lower()}"],
+                    ["<info>priority</>", f" : {repo.priority.name.lower()}"],
                     ["<info>url</>", f" : {repo.url}"],
-                    ["<info>active auth</info>", active_state]
-                    if creds and creds.valid()
-                    else ["<info>auth</info>", " : <c1>no</c1>"],
+                    (
+                        ["<info>active auth</info>", active_state]
+                        if creds and creds.valid()
+                        else ["<info>auth</info>", " : <c1>no</c1>"]
+                    ),
                     ["", ""],
                 ]
                 table.add_rows(rows)
@@ -155,7 +142,7 @@ class RepoUseCommand(Command):
 
             return 0
         except Exception as e:
-            self.line(f"[DynamicRepos#{type(self)}]: <error>{e}</>")
+            self.line(f"[DynamicRepos#{type(self).name}]: <error>{e}</>")
             return -1
 
 
