@@ -7,11 +7,8 @@ from datetime import timedelta
 from functools import cached_property
 from pathlib import Path
 from typing import Any
-from typing import Dict
-from typing import List
 from typing import Literal
-from typing import Optional
-from typing import Union
+from typing import OrderedDict
 
 import tomli
 import tomlkit
@@ -21,8 +18,7 @@ from poetry.repositories.repository_pool import Priority
 from pydantic import BaseModel
 from pydantic import Field
 from pydantic import field_validator
-from pydantic import model_validator
-from pydantic_core.core_schema import FieldValidationInfo
+from pydantic_core.core_schema import ValidationInfo
 from pytz import UTC
 from tomlkit.items import KeyType
 from tomlkit.items import SingleKey
@@ -36,7 +32,7 @@ logger = logging.getLogger(__name__)
 class Auth(BaseModel):
     authtype: str
     cache: bool = False
-    timeout: Optional[int] = None
+    timeout: int | None = None
 
     def to_table(self) -> Table:
         table = tomlkit.table(is_super_table=True)
@@ -56,8 +52,8 @@ class CodeArtifactAuth(Auth):
     authtype: Literal["codeartifact"] = "codeartifact"
     domain: str
     owner: str
-    region: Optional[str] = None
-    profile: Optional[str] = None
+    region: str | None = None
+    profile: str | None = None
 
     def to_table(self) -> Table:
         table = super().to_table()
@@ -103,7 +99,7 @@ class CachedCredentialSet(BaseModel):
     VALID_WINDOW: int = 30
 
     authtype: str
-    expires: Optional[datetime] = None
+    expires: datetime | None = None
     fingerprint: str
 
     def valid(self) -> bool:
@@ -125,15 +121,13 @@ class CachedCredentialSet(BaseModel):
 
 class Repo(BaseModel):
     name: str
-    url: Optional[str] = None
-    auth: Union[None, CodeArtifactAuth, BasicAuth] = Field(None, discriminator="authtype")
+    url: str | None = None
+    auth: None | CodeArtifactAuth | BasicAuth = Field(None, discriminator="authtype")
     enabled: bool
-    default: Optional[bool] = None
-    secondary: Optional[bool] = None
-    priority: Optional[Priority] = None
+    priority: Priority
 
     @field_validator("*", mode="before")
-    def coerce_priority(cls, v: Any, info: FieldValidationInfo) -> Any:
+    def coerce_priority(cls, v: Any, info: ValidationInfo) -> Any:
         if info.field_name == "priority":
             if isinstance(v, Priority):
                 return v
@@ -145,42 +139,34 @@ class Repo(BaseModel):
         else:
             return v
 
-    @model_validator(mode="before")
-    def ensure_priority(cls, d: Dict[Any, Any]) -> Dict[Any, Any]:
-        if "priority" not in d.keys() and (
-            "secondary" not in d.keys() or "default" not in d.keys()
-        ):
-            raise ValueError(
-                "Either priority (1.4+) or default + secondary properties must be set on all declared repos"
-            )
-        return d
+    def to_source_dict(self) -> dict[str, Any]:
+        source_dict = {"name": self.name, "priority": self.priority.name.lower()}
+        if self.url:
+            source_dict["url"] = self.url
+        return source_dict
 
     def to_table(self) -> Table:
         table = tomlkit.table(is_super_table=True)
         table.append("enabled", self.enabled)
-        table.append("url", self.url)
+        if self.url:
+            table.append("url", self.url)
         if self.auth:
             auth_table = self.auth.to_table()
             for key in dict.keys(auth_table):
                 table.append(SingleKey(f"auth.{key}", KeyType.Bare), auth_table.get(key))
-        if self.default:
-            table.append("default", self.default)
-        if self.secondary:
-            table.append("secondary", self.secondary)
-        if self.priority:
-            table.append("priority", self.priority.name.lower())
+        table.append("priority", self.priority.name.lower())
         return table
 
 
 class RepoManager:
-    _repos: Dict[str, Repo] = {}
+    _repos: OrderedDict[str, Repo] = OrderedDict()
 
     @classmethod
-    def entries(cls) -> List[str]:
+    def entries(cls) -> list[str]:
         return list(cls._repos.keys())
 
     @classmethod
-    def get(cls, name: str) -> Optional[Repo]:
+    def get(cls, name: str) -> Repo | None:
         if name in cls._repos.keys():
             return cls._repos[name]
         return None
@@ -188,7 +174,7 @@ class RepoManager:
     @classmethod
     def load(self, file_path: Path = REPO_FILE_PATH) -> None:
         logger.debug(f"Loading repositories from {file_path} ({file_path.exists()})")
-        self._repos = {}
+        self._repos = OrderedDict()
         if file_path.exists():
             with file_path.open("r") as fh:
                 doc = tomli.loads(fh.read())
