@@ -3,16 +3,13 @@ from typing import List
 from typing import Type
 
 from cleo.io.io import IO
-from poetry.config.source import Source
 from poetry.console.application import Application
 from poetry.console.commands.command import Command
+from poetry.factory import Factory
 from poetry.plugins.application_plugin import ApplicationPlugin
 from poetry.plugins.plugin import Plugin
 from poetry.poetry import Poetry
-from poetry.repositories.repository_pool import RepositoryPool
 from poetry.utils.password_manager import PasswordManager
-from poetry.utils.source import source_to_table
-from tomlkit.items import AoT
 
 from appcensus.dynamic_repos import REPO_FILE_PATH
 from appcensus.dynamic_repos.auth import CredentialCache
@@ -26,83 +23,64 @@ from appcensus.dynamic_repos.commands import RepoShowCredentials
 from appcensus.dynamic_repos.commands import RepoUseCommand
 from appcensus.dynamic_repos.models import Repo
 from appcensus.dynamic_repos.models import RepoManager
+from appcensus.dynamic_repos.pool_manager import PoolManager
 from appcensus.dynamic_repos.repo_collector import RepoCollector
-from appcensus.dynamic_repos.source_manager import SourceManager
 
 logger = logging.getLogger(__name__)
 
 
 class DynamicRepos(Plugin):
-    def _new_source(self, repo: Repo) -> Source:
-        if repo.priority:
-            return Source(
-                name=repo.name,
-                url=repo.url,
-                default=repo.default,
-                secondary=repo.secondary,
-                priority=repo.priority,
-            )
-        return Source(name=repo.name, url=repo.url, default=repo.default, secondary=repo.secondary)
+    _create_pool = Factory.create_pool
 
-    def _check_source(self, existing_sources: List[Source], new_source: Source) -> bool:
-        if new_source.default and new_source.secondary:  # type: ignore [attr-defined]
-            raise ValueError(f"Repo {new_source.name} cannot be default and secondary - pick one")
-
-        for source in existing_sources:
-            if source == new_source:
+    def _check_repo(self, existing_repos: List[Repo], new_repo: Repo) -> bool:
+        for repo in existing_repos:
+            if repo == new_repo:
                 raise ValueError(
-                    f"Identical source <c1>{new_source.name}</> already exists. Perhaps you have a declaration in"
+                    f"Identical source <c1>{new_repo.name}</> already exists. Perhaps you have a declaration in"
                     " pyproject.toml. You should resolve the redundancy to prevent conflict."
                 )
 
-            if source.name == new_source.name:
+            if repo.name == new_repo.name:
                 raise ValueError(
-                    f"Inconsistent source with name <c1>{new_source.name}</c1> already exists."
+                    f"Inconsistent source with name <c1>{new_repo.name}</c1> already exists."
                     " Please reconile this."
                 )
 
-            if source.default and new_source.default:  # type: ignore [attr-defined]
-                raise ValueError(
-                    f"Source with name <c1>{source.name}</c1> is already set to default."
-                    f" Only one default source can be configured at a time. <c1>{new_source.name}</c1>"
-                    " will be rejected."
-                )
         return True
 
-    def _configure_sources(self, poetry: Poetry, io: IO) -> None:
-        logger.debug("Configuring sources ...")
+    def _configure_repositories(self, poetry: Poetry, io: IO) -> None:
+        logger.debug("Configuring repositories ...")
 
-        existing_sources = RepoCollector(poetry.pool).repositories()
+        existing_repos = RepoCollector(poetry.pool).repositories()
 
-        logger.debug(f"Beginning with {len(existing_sources)} existing sources")
-        for source in existing_sources:
-            logger.debug(f"- {source}")
+        logger.debug(f"Beginning with {len(existing_repos)} existing repositories")
+        for repo in existing_repos:
+            logger.debug(f"- {repo}")
 
-        new_sources = AoT([source_to_table(source) for source in existing_sources])
+        new_repositories: List[Repo] = []
 
         for name in RepoManager.entries():
-            logger.debug(f"repo {name}")
             repo = RepoManager.get(name)
             if repo.enabled:
                 try:
-                    new_source = self._new_source(repo)
-                    if self._check_source(existing_sources, new_source):
+                    if self._check_repo(existing_repos, repo):
                         if repo.auth:
                             try:
+                                logger.debug(f"Authorizing repo {repo.name} ...")
                                 pm = PasswordManager(poetry.config)
                                 CredentialManager.authorize(pm, repo)
                             finally:
                                 CredentialCache.save()
-                        logger.debug(f"Adding {new_source.name}")
-                        new_sources.append(source_to_table(new_source))
+
+                        logger.debug(f"Adding {repo.name}")
+                        new_repositories.append(repo)
                 except Exception as e:
                     self._exceptional_error(io, e)
                     return
 
         # configure new sources
-        logger.debug(f"Configuring {len(new_sources)} sources ...")
-        poetry._pool = RepositoryPool()
-        SourceManager().add_sources(poetry, new_sources, io)
+        logger.debug(f"Configuring {len(new_repositories)} sources ...")
+        PoolManager(poetry, io).create_pool(new_repositories)
 
     def _exceptional_error(self, io: IO, e: Exception) -> None:
         logger.error(e, exc_info=True)
@@ -112,7 +90,7 @@ class DynamicRepos(Plugin):
         logger.debug("Activating appcensus.dynamic_repos")
         if not REPO_FILE_PATH.exists():
             return
-        self._configure_sources(poetry, io)
+        self._configure_repositories(poetry, io)
 
 
 class DynamicReposApplication(ApplicationPlugin):
