@@ -31,7 +31,7 @@ class PrioritizedRepoStrategy(RepoStrategy):
     def repositories(self) -> List[Source]:
         repos = []
         logger.debug("Collecting repos from a prioritized repo:")
-        for repo in self._pool.repositories:
+        for repo in self._pool.all_repositories:
             if type(repo) is PyPiRepository:
                 continue
             prio = self._pool.get_priority(repo.name)
